==> dl.php?src=linea21_2_3_0.zip: linea21/languages/es/lang_resources.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['resources']['name']='Fuente';
$lang['resources']['confirm_add'] = "Fuente añadida correctamente";
$lang['resources']['confirm_mod'] = "Fuente actualizada correctamente";
$lang['resources']['confirm_sup'] ="Fuente eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['resources']['add']= 'Añadir nueva '.$lang['resources']['name'];
$lang['resources']['mod']= 'Editar '.$lang['resources']['name'];
$lang['resources']['sup']= 'Eliminar '.$lang['resources']['name'];
$lang['resources']['det']= ucfirst($lang['resources']['name']) . ' detalles';
$lang['resources']['list']= 'Ver fuentes';
$lang['resources']['go_back']='Volver';

/*	nommage des 'parents'
 *  	*/
$lang['resources']['publication_type']='publicación';
$lang['resources']['workshop_type']='informe';

/*	nommage rubrique add / mod /det
 *  	*/
$lang['resources']['add_title']='Añadir valores a la nueva '.$lang['resources']['name'];
$lang['resources']['mod_title']='Editar valores de '.$lang['resources']['name'];


/*	nommage élément rubrique
 *  	*/
$lang['resources']['supp_info']='Ha seleccionado eliminar fuente del tipo ';
$lang['resources']['next']='siguiente :';
$lang['resources']['link_res']='enlace';
$lang['resources']['biblio_res']='bibliográfica';
$lang['resources']['multi_res']='multimedia';

$lang['resources']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['resources']['url_mask']='Máscara de texto';
$lang['resources']['url_visual_test']='revisar valores';

$lang['resources']['biblio_author']='autor';
$lang['resources']['biblio_title']='título del libro';
$lang['resources']['biblio_sub_title']='subtítulo';
$lang['resources']['biblio_editor']='editor';
$lang['resources']['biblio_published_date']='fecha de publicación';

$lang['resources']['multi_name']='nombre';
$lang['resources']['multi_description']='descripción';

/*	check integrité des données
 *  	*/
$lang['resources']['no_url']='Por favor, inserte '.$lang['resources']['url'];
$lang['resources']['invalid_protocol']='Protocolo no válido, por favor revise la sintaxis';
$lang['resources']['invalid_link']='El enlace comienza con \'http://\'.';
$lang['resources']['server_noresponse']='Error en la url: no hay respuesta del servidor';

$lang['resources']['biblio_no_author']='El autor es requerido';
$lang['resources']['biblio_no_title']='El título es requerido';

$lang['resources']['multi_no_name']='El nombre del documento es requerido';
$lang['resources']['multi_no_description']='La descripción del documento es requerida';


/*	nommage quickbox
 *  	*/
$lang['resources']['qb_titleadd']=' fuentes agregadas recientemente';
$lang['resources']['qb_titlemod']=' fuentes modificadas recientemente';
$lang['resources']['qb_titlesup']=' fuentes eliminadas recientemente';
$lang['resources']['qb_titlepubli']=' últimas publicaciones';
$lang['resources']['qb_title_type_W']=' en el informe';
$lang['resources']['qb_title_type_P']=' en la publicación';


/*	divers
 *  	*/
$lang['resources']['no_link']="No existe sitio web asociado a esta publicación";
$lang['resources']['del_link']="Eliminar enlace";
$lang['resources']['mod_link']="Editar enlace";

$lang['resources']['no_multi']="No existen documentos asociados a esta publicación";
$lang['resources']['del_multi']="Eliminar documento";
$lang['resources']['mod_multi']="Editar documento";

$lang['resources']['no_biblio']="No existen referencias bibliográficas asociadas a esta publicación";
$lang['resources']['del_biblio']="Eliminar referencia";
$lang['resources']['mod_biblio']="Actualizar referencia";

$lang['resources']['no_part']="No existen apartados asociados a esta publicación";
$lang['resources']['del_part']="Eliminar apartado";
$lang['resources']['mod_part']="Editar apartado";


/*	rubrique d'aide
 *  	*/
$lang['resources']['help_add1']='Para añadir una nueva fuente, inserte la información requerida en el cuestionario.';
$lang['resources']['help_add2']='Completado el cuestionario, revise los valores en el resumen.';
$lang['resources']['help_add3']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';

$lang['resources']['help_list1']='Para mas información haga clic en el título de la fuente.';
$lang['resources']['help_list2']='Para eliminar una fuente, haga clic en el icono "eliminar fuente".';
$lang['resources']['help_list3']='Para editar una fuente, haga clic en el icono "editar fuente".';
$lang['resources']['help_list4']='Para visualizar fuentes según su estado, mostrar por estados.';
$lang['resources']['help_list5']='Para añadir una nueva fuente, inserte la información requerida en el formulario';

$lang['resources']['help_mod1']='Puede actualizar todos los campos del formulario.';
$lang['resources']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['resources']['help_mod3']='Validado el resumen, haga clic the "revisar valores" si desea realizar cambios.';

$lang['resources']['help_sup1']='Para cancelar la eliminación, haga clic en "cancelar".';
?>

==> dl.php?src=linea21_2_5_0.zip: linea21/languages/es/lang_resources.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


/*	nommage des modules
 *  	*/
$lang['resources']['name']='Fuente';
$lang['resources']['confirm_add'] = "Fuente añadida correctamente";
$lang['resources']['confirm_mod'] = "Fuente actualizada correctamente";
$lang['resources']['confirm_sup'] ="Fuente eliminada correctamente";


/*	nommage rubrique module
 *  	*/
$lang['resources']['add']= 'Añadir nueva '.$lang['resources']['name'];
$lang['resources']['mod']= 'Editar '.$lang['resources']['name'];
$lang['resources']['sup']= 'Eliminar '.$lang['resources']['name'];
$lang['resources']['det']= ucfirst($lang['resources']['name']) . ' detalles';
$lang['resources']['list']= 'Ver fuentes';
$lang['resources']['go_back']='Volver';

/*	nommage des 'parents'
 *  	*/
$lang['resources']['publication_type']='publicación';
$lang['resources']['workshop_type']='informe';

/*	nommage rubrique add / mod /det
 *  	*/
$lang['resources']['add_title']='Añadir valores a la nueva '.$lang['resources']['name'];
$lang['resources']['mod_title']='Editar valores de '.$lang['resources']['name'];


/*	nommage élément rubrique
 *  	*/
$lang['resources']['supp_info']='Ha seleccionado eliminar fuente del tipo ';
$lang['resources']['next']='siguiente :';
$lang['resources']['link_res']='enlace';
$lang['resources']['biblio_res']='bibliográfica';
$lang['resources']['multi_res']='recursos';

$lang['resources']['url']='<acronym title="Uniform Resource Locator">URL</acronym>';
$lang['resources']['url_mask']='Máscara de texto';
$lang['resources']['url_visual_test']='revisar valores';

$lang['resources']['biblio_author']='autor';
$lang['resources']['biblio_title']='título del libro';
$lang['resources']['biblio_sub_title']='subtítulo';
$lang['resources']['biblio_editor']='editor';
$lang['resources']['biblio_published_date']='fecha de publicación';

$lang['resources']['multi_name']='nombre';
$lang['resources']['multi_description']='descripción';

/*	check integrité des données
 *  	*/
$lang['resources']['no_url']='Por favor, inserte '.$lang['resources']['url'];
$lang['resources']['invalid_protocol']='Protocolo no válido, por favor revise la sintaxis';
$lang['resources']['invalid_link']='El enlace comienza con \'http://\'.';
$lang['resources']['server_noresponse']='Error en la url: no hay respuesta del servidor';

$lang['resources']['biblio_no_author']='El autor es requerido';
$lang['resources']['biblio_no_title']='El título es requerido';

$lang['resources']['multi_no_name']='El nombre del documento es requerido';
$lang['resources']['multi_no_description']='La descripción del documento es requerida';


/*	nommage quickbox
 *  	*/
$lang['resources']['qb_titleadd']=' fuentes agregadas recientemente';
$lang['resources']['qb_titlemod']=' fuentes modificadas recientemente';
$lang['resources']['qb_titlesup']=' fuentes eliminadas recientemente';
$lang['resources']['qb_titlepubli']=' últimas publicaciones';
$lang['resources']['qb_title_type_W']=' en el informe';
$lang['resources']['qb_title_type_P']=' en la publicación';


/*	divers
 *  	*/
$lang['resources']['no_link']="No existe sitio web asociado a esta publicación";
$lang['resources']['del_link']="Eliminar enlace";
$lang['resources']['mod_link']="Editar enlace";

$lang['resources']['no_multi']="No existen documentos asociados a esta publicación";
$lang['resources']['del_multi']="Eliminar documento";
$lang['resources']['mod_multi']="Editar documento";

$lang['resources']['no_biblio']="No existen referencias bibliográficas asociadas a esta publicación";
$lang['resources']['del_biblio']="Eliminar referencia";
$lang['resources']['mod_biblio']="Actualizar referencia";

$lang['resources']['no_part']="No existen apartados asociados a esta publicación";
$lang['resources']['del_part']="Eliminar apartado";
$lang['resources']['mod_part']="Editar apartado";


/*	rubrique d'aide
 *  	*/
$lang['resources']['help_add1']='Para añadir una nueva fuente, inserte la información requerida en el cuestionario.';
$lang['resources']['help_add2']='Completado el cuestionario, revise los valores en el resumen.';
$lang['resources']['help_add3']='Validado el resumen, haga clic en "revisar valores" si desea realizar cambios.';

$lang['resources']['help_list1']='Para mas información haga clic en el título de la fuente.';
$lang['resources']['help_list2']='Para eliminar una fuente, haga clic en el icono "eliminar fuente".';
$lang['resources']['help_list3']='Para editar una fuente, haga clic en el icono "editar fuente".';
$lang['resources']['help_list4']='Para visualizar fuentes según su estado, mostrar por estados.';
$lang['resources']['help_list5']='Para añadir una nueva fuente, inserte la información requerida en el formulario';

$lang['resources']['help_mod1']='Puede actualizar todos los campos del formulario.';
$lang['resources']['help_mod2']='Completado el formulario, revise los valores en el resumen.';
$lang['resources']['help_mod3']='Validado el resumen, haga clic the "revisar valores" si desea realizar cambios.';

$lang['resources']['help_sup1']='Para cancelar la eliminación, haga clic en "cancelar".';
?>
